diff Core/HttpServer/HttpOutput.h @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents a15e90e5d6fc
children fe180eae201d
line wrap: on
line diff
--- a/Core/HttpServer/HttpOutput.h	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/HttpServer/HttpOutput.h	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -25,12 +25,12 @@
 #include "../Enumerations.h"
 #include "../FileStorage.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   class HttpOutput
   {
   private:
-    void SendHeaderInternal(Palanthir_HttpStatus status);
+    void SendHeaderInternal(Orthanc_HttpStatus status);
 
     void SendOkHeader(const char* contentType,
                       bool hasContentLength,
@@ -56,7 +56,7 @@
 
     void SendMethodNotAllowedError(const std::string& allowed);
 
-    void SendHeader(Palanthir_HttpStatus status);
+    void SendHeader(Orthanc_HttpStatus status);
 
 
     // Higher-level constructs to send entire files or buffers -------------------
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium